Commands#
Target |
What it does |
|---|---|
|
Builds documentation (also writes |
|
Verifies documentation correctness |
|
Builds combined documentation with all external dependencies included |
|
Reads the pre-computed metrics.json and fails if coverage thresholds are not met |
|
Creates a live_preview of the documentation viewable in a local server |
|
Creates a live_preview of the full documentation with all dependencies viewable in a local server |
|
Sets up a Python venv for esbonio (Remember to restart VS Code!) |
Internal targets (do not use directly)#
Target |
What it does |
|---|---|
|
Creates a ‘needs.json’ file |
|
Provides all the documentation source files |
If the docs() macro is called with a custom name (see Bazel macro: docs), every
target above is prefixed with it instead, e.g. name = "foo" yields //:foo,
//:foo_check, //:foo_needs_json, //:foo_ide_support, etc.